@@ -30,4 +30,4 @@ types_mapping = {
 }
 
 
-datetime_types = ['TIMESTAMP', 'DATETIME', 'DATE']
\ No newline at end of file
+datetime_types = ["TIMESTAMP", "DATETIME", "DATE"]
